/* ************************************************************************** */
/*                                       _____           _                    */
/*  libp7/internals/log.h               |_   _|__  _   _| |__   ___ _   _     */
/*  | Project: libp7                      | |/ _ \| | | | '_ \ / _ \ | | |    */
/*                                        | | (_) | |_| | | | |  __/ |_| |    */
/*  By: thomas <thomas@touhey.fr>         |_|\___/ \__,_|_| |_|\___|\__, |.fr */
/*  Last updated: 2017/01/04 15:01:48                               |___/     */
/*                                                                            */
/* ************************************************************************** */
#ifndef LIBP7_INTERNALS_LOG_H
# define LIBP7_INTERNALS_LOG_H
# include <stdio.h>

/* ************************************************************************** */
/*  Log utility                                                               */
/* ************************************************************************** */
/* Log level */
# define ll_info 0
# define ll_warn 1
# define ll_error 2
# define ll_fatal 3
# define ll_none 4

/* Check log level */
# ifdef P7_DISABLED_FILE
#  undef LOGLEVEL
#  define LOGLEVEL ll_none
# endif

/* Macros */
#  define logr(P, S, ...) fprintf(stderr, P "%s: " S "\n", \
	__FUNCTION__, ##__VA_ARGS__)
#  define  log(P, S, ...) fprintf(stderr, P "%s: " S "\n", handle->_name, \
	__FUNCTION__, ##__VA_ARGS__)
#  define logm(S, M, N)   p7_log_mem(S, M, N, handle->_name)

# if LOGLEVEL <= ll_info
#  define logr_info(S, ...) logr("[libp7 info]  ",   S, ##__VA_ARGS__)
#  define log_info(S, ...)   log("[libp7%s info]  ", S, ##__VA_ARGS__)
#  define logm_info(M, N)   logm("[libp7%s info]  ", M, N)
# else
#  define logr_info(S, ...)
#  define log_info(S, ...)
#  define logm_info(M, N)
# endif

# if LOGLEVEL <= ll_warn
#  define logr_warn(S, ...) logr("[libp7 warn]  ",   S, ##__VA_ARGS__)
#  define  log_warn(S, ...) log("[libp7%s warn]  ", S, ##__VA_ARGS__)
#  define   logm_warn(M, N) logm("[libp7%s warn]  ", M, N)
# else
#  define logr_warn(S, ...)
#  define log_warn(S, ...)
#  define logm_warn(M, N)
# endif

# if LOGLEVEL <= ll_error
#  define logr_error(S, ...) logr("[libp7 error] ",   S, ##__VA_ARGS__)
#  define  log_error(S, ...)  log("[libp7%s error] ", S, ##__VA_ARGS__)
# else
#  define logr_error(S, ...)
#  define  log_error(S, ...)
# endif

# if LOGLEVEL <= ll_fatal
#  define logr_fatal(S, ...) logr("[libp7 fatal] ",   S, ##__VA_ARGS__)
#  define  log_fatal(S, ...) log("[libp7%s fatal] ", S, ##__VA_ARGS__)
# else
#  define logr_fatal(S, ...)
#  define  log_fatal(S, ...)
# endif

/* Functions prototypes */
void p7_log_mem(const char *prefix, const void *m, size_t n, ...);

/* ************************************************************************** */
/*  Get messages from codes                                                   */
/* ************************************************************************** */
const char *p7_getcmdstring(unsigned int code);
const char *p7_geterrstring(p7_errcode_t code);
const char *p7_gettermstring(p7_termtype_t code);
const char *p7_getowstring(p7_commandoverwrite_t code);

#endif /* LIBP7_INTERNALS_LOG_H */
