/* ************************************************************************** */
/*                                       _____           _                    */
/*  handle/stream.c                     |_   _|__  _   _| |__   ___ _   _     */
/*  | Project: libp7                      | |/ _ \| | | | '_ \ / _ \ | | |    */
/*                                        | | (_) | |_| | | | |  __/ |_| |    */
/*  By: thomas <thomas@touhey.fr>         |_|\___/ \__,_|_| |_|\___|\__, |.fr */
/*  Last updated: 2017/01/04 15:01:48                               |___/     */
/*                                                                            */
/* ************************************************************************** */
#include <libp7/internals.h>
#include <string.h>

/**
 *	p7_read:
 *	Receive raw data via a P7 Stream.
 *
 *	@arg	stream		the P7 stream.
 *	@arg	dest		the data destination.
 *	@arg	size		the data size.
 *	@arg	timeout		the timeout in milliseconds.
 *	@return				the error code (0 if ok).
 */

int p7_read(p7_stream_t *stream, void *dest, size_t size, unsigned int timeout)
{
	if (!stream->read) return (p7_error_noread);
	return ((*stream->read)(stream->cookie,
		(unsigned char*)dest, size, timeout));
}

/**
 *	p7_write:
 *	Send raw data via a P7 Stream.
 *
 *	@arg	stream		the P7 stream.
 *	@arg	data		the data.
 *	@arg	size		the data size.
 *	@return				the error code (0 if ok).
 */

int p7_write(p7_stream_t *stream, const void *data, size_t size)
{
	if (!stream->write) return (p7_error_nowrite);
	return ((*stream->write)(stream->cookie,
		(const unsigned char*)data, size));
}

/**
 *	p7_setcomm:
 *	Set a P7 Stream baud speed.
 *
 *	@arg	stream		the P7 stream.
 *	@arg	speed		the speed (use one of the P7_B* constants)
 *	@arg	parity		the parity (P7_PARITY_*)
 *	@arg	stopbits	the parity (P7_*STOPBIT*)
 *	@return				the error code (0 if ok).
 */

int p7_setcomm(p7_stream_t *stream, int speed, int parity, int stopbits)
{
	if (!stream->setcomm) return (0);
	return ((*stream->setcomm)(stream->cookie, speed, parity, stopbits));
}
