/* ************************************************************************** */
/*                                       _____           _                    */
/*  protocol/copy.c                     |_   _|__  _   _| |__   ___ _   _     */
/*  | Project: libp7                      | |/ _ \| | | | '_ \ / _ \ | | |    */
/*                                        | | (_) | |_| | | | |  __/ |_| |    */
/*  By: thomas <thomas@touhey.fr>         |_|\___/ \__,_|_| |_|\___|\__, |.fr */
/*  Last updated: 2017/01/04 15:01:48                               |___/     */
/*                                                                            */
/* ************************************************************************** */
#include <libp7/internals.h>

/**
 *	p7_copy:
 *	Copies a file into another on distant device.
 *
 *	@arg	handle		the libp7 handle
 *	@arg	dirname		the directory name
 *	@arg	filename	the filename
 *	@arg	newdir		the new directory name
 *	@arg	newname		the new filename
 *	@arg	devname		the device name
 *	@return				if it worked
 */

int p7_copy(p7_handle_t *handle,
	const char *dirname, const char *filename,
	const char *newdir, const char *newname, const char *devname)
{
	int err;

	/* make checks */
	chk_required_filename(filename);
	chk_required_filename(newname);
	chk_dirname(dirname);
	chk_dirname(newdir);
	chk_handle(handle);
	chk_active(handle);

	/* send command packet */
	log_info("sending command");
	if ((err = p7_send_cmdfls_copyfile(handle, dirname, filename, newdir,
		newname, devname))) {
		log_fatal("couldn't send command/get its response");
		return (err);
	} else if (response.type != p7_pt_ack && response.type != p7_pt_error) {
		log_fatal("received an invalid answer");
		return (p7_error_unknown);
	}

	/* - check error - */
	if (response.type == p7_pt_error) switch (response.code) {
		/* overwrite impossible */
		case p7_err_dont_overwrite:
		case p7_err_other:
			log_error("overwrite impossible");
			return (p7_error_unsupported_device);

		/* memory full */
		case p7_err_fullmem:
			log_error("distant memory is full");
			return (p7_error_fullmem);

		/* resend error - just here to stfu the warning */
		default: return (p7_error_unknown);
	}

	/* we're done */
	return (0);
}
