/* ************************************************************************** */
/*                                       _____           _                    */
/*  protocol/createdir.c                |_   _|__  _   _| |__   ___ _   _     */
/*  | Project: libp7                      | |/ _ \| | | | '_ \ / _ \ | | |    */
/*                                        | | (_) | |_| | | | |  __/ |_| |    */
/*  By: thomas <thomas@touhey.fr>         |_|\___/ \__,_|_| |_|\___|\__, |.fr */
/*  Last updated: 2017/01/27 14:57:34                               |___/     */
/*                                                                            */
/* ************************************************************************** */
#include <libp7/internals.h>

/**
 *	p7_createdir:
 *	Create a distant directory.
 *
 *	@arg	handle		the libp7 handle
 *	@arg	dirname		the directory name
 *	@arg	devname		the device name
 *	@return				the error code (0 if ok)
 */

int p7_createdir(p7_handle_t *handle, const char *dirname, const char *devname)
{
	int err;

	/* make checks */
	chk_handle(handle);
	chk_active(handle);
	chk_dirname(dirname);

	/* send command packet */
	log_info("sending command");
	if ((err = p7_send_cmdfls_mkdir(handle, dirname, devname))) {
		log_fatal("couldn't send command/get its response");
		return (err);
	} else if (response.type != p7_pt_ack && response.type != p7_pt_error) {
		log_fatal("received an invalid answer");
		return (p7_error_unknown);
	}

	/* check error */
	if (response.type == p7_pt_error) switch (response.code) {
		default:
			log_fatal("unknown/unmanaged error");
			return (p7_error_unknown);
	}

	/* we're done */
	return (0);
}
