/* ************************************************************************** */
/*                                       _____           _                    */
/*  protocol/getcapacity.c              |_   _|__  _   _| |__   ___ _   _     */
/*  | Project: libp7                      | |/ _ \| | | | '_ \ / _ \ | | |    */
/*                                        | | (_) | |_| | | | |  __/ |_| |    */
/*  By: thomas <thomas@touhey.fr>         |_|\___/ \__,_|_| |_|\___|\__, |.fr */
/*  Last updated: 2017/01/27 14:57:59                               |___/     */
/*                                                                            */
/* ************************************************************************** */
#include <libp7/internals.h>

/**
 *	p7_getfreemem:
 *	Request a device's capacity.
 *
 *	@arg	handle		the libp7 handle.
 *	@arg	devname		the device name.
 *	@arg	capacity	pointer to the capacity to fill.
 *	@return				if there was an error.
 */

int p7_getfreemem(p7_handle_t *handle, const char *devname,
	p7uint_t *capacity)
{
	int err;
	/* make checks */
	chk_handle(handle);
	chk_active(handle);

	/* send command packet */
	log_info("sending capacity transmit request");
	if ((err = p7_send_cmdfls_reqcapacity(handle, devname))) {
		log_fatal("couldn't send request/didn't receive answer");
		return (err);
	}

	/* check response packet */
	if (response.type == p7_pt_error
	 && response.code == p7_err_other) {
		log_fatal("filesystem probably doesn't exist");
		return (p7_error_unsupported_device);
	} else if (response.type != p7_pt_ack) {
		log_fatal("didn't receive ack or known error...");
		return (p7_error_unknown);
	}

	/* swap roles */
	log_info("sending roleswap");
	if ((err = p7_send_roleswp(handle))) {
		log_fatal("couldn't swap roles");
		return (err);
	} else if (response.type != p7_pt_cmd || response.code != 0x4C
	 || !response.args[4]) {
		log_fatal("didn't receive expected command");
		return (p7_error_unknown);
	}

	/* decode thingy */
	*capacity = response.filesize;

	/* ack and check for the roleswap */
	log_info("return ack and wait for roleswp");
	if ((err = p7_send_ack(handle, 1))) {
		log_fatal("unable to send ack.");
		return (err);
	} else if (response.type != p7_pt_roleswp)
		return (p7_error_unknown);

	/* no error! */
	return (0);
}
