/* ************************************************************************** */
/*                                       _____           _                    */
/*  protocol/resetflash.c               |_   _|__  _   _| |__   ___ _   _     */
/*  | Project: libp7                      | |/ _ \| | | | '_ \ / _ \ | | |    */
/*                                        | | (_) | |_| | | | |  __/ |_| |    */
/*  By: thomas <thomas@touhey.fr>         |_|\___/ \__,_|_| |_|\___|\__, |.fr */
/*  Last updated: 2017/01/04 15:01:48                               |___/     */
/*                                                                            */
/* ************************************************************************** */
#include <libp7/internals.h>

/**
 *	p7_reset:
 *	Reset a distant filesystem.
 *
 *	@arg	handle		the libp7 handle
 *	@arg	devname		the device name
 *	@return				if it worked
 */

int p7_reset(p7_handle_t *handle, const char *devname)
{
	int err;

	/* make checks */
	chk_handle(handle);
	chk_active(handle);

	/* send command */
	log_info("sending command");
	if ((err = p7_send_cmdfls_reset(handle, devname))) {
		log_fatal("couldn't send command/receive its answer");
		return (err);
	} else if (response.type == p7_pt_error
	 && response.code == p7_err_other) {
		log_fatal("storage device doesn't exist");
		return (p7_error_unsupported_device);
	} else if (response.type != p7_pt_ack) {
		log_fatal("response wasn't ack");
		return (p7_error_unknown);
	}

	/* we're done */
	return (0);
}
