/* ************************************************************************** */
/*                                       _____           _                    */
/*  utils/ascii.c                       |_   _|__  _   _| |__   ___ _   _     */
/*  | Project: libp7                      | |/ _ \| | | | '_ \ / _ \ | | |    */
/*                                        | | (_) | |_| | | | |  __/ |_| |    */
/*  By: thomas <thomas@touhey.fr>         |_|\___/ \__,_|_| |_|\___|\__, |.fr */
/*  Last updated: 2017/01/04 15:01:48                               |___/     */
/*                                                                            */
/* ************************************************************************** */
#include <libp7/internals.h>
#include <ctype.h>

/* ************************************************************************** */
/*  ASCII-HEX utilities                                                       */
/* ************************************************************************** */
/**
 *	p7_putascii:
 *	Put a number in ASCII-hex, in a n-dimensionned field.
 *
 *	@arg	p		pointer where to put ASCII number
 *	@arg	i		ASCII number
 *	@arg	n		the size of the field
 */

void p7_putascii(unsigned char *p, p7uint_t i, int n)
{
	p += (n - 1);
	while (n--) {
		int j = i % 16;
		*p-- = j >= 10 ? j - 10 + 'A' : j + '0';
		i /= 16;
	}
}

/**
 *	p7_getascii:
 *	Gets a number in ASCII-hex, in a n-dimensionned field.
 *
 *	@arg	p		pointer where the ASCII number is
 *	@arg	n		the size of the field
 *	@return			the number
 */

p7uint_t p7_getascii(const unsigned char *p, int n)
{
	p7uint_t i = 0;

	while (n--) {
		p7uint_t j = *p++;
		j = isdigit(j) ? j - '0' : j + 10 - 'A';
		i = i * 16 + j;
	}
	return (i);
}

/* ************************************************************************** */
/*  BIN-HEX to BIN-DEC (BCD) utilities                                        */
/* ************************************************************************** */
/**
 *	p7_getdec:
 *	Get decimal of hex.
 *
 *	@arg	h		the hex number.
 *	@return			the decimal number.
 */

p7uint_t p7_getdec(p7uint_t h)
{
	return ((h & 15) + ((h >> 4) & 15) * 10
		+ ((h >> 8) & 15) * 100 + ((h >> 12) & 15) * 1000
		+ ((h >> 16) & 15) * 10000 + ((h >> 20) & 15) * 1000000
		+ ((h >> 24 & 15) * 10000000 + ((h >> 28) & 15) * 100000000));
}

/**
 *	p7_gethex:
 *	Get hex of decimal.
 *
 *	@arg	d		the decimal number.
 *	@return			the hex number.
 */

p7uint_t p7_gethex(p7uint_t d)
{
	return ((d % 10) + ((d / 10 % 10) << 4)
		+ ((d / 100 % 10) << 8) + ((d / 1000 % 10) << 12)
		+ ((d / 10000 % 10) << 16) + ((d / 100000 % 10) << 20)
		+ ((d / 1000000) << 24) + ((d / 10000000) << 28));
}
