/* ************************************************************************** */
/*                                       _____           _                    */
/*  utils/checksum.c                    |_   _|__  _   _| |__   ___ _   _     */
/*  | Project: libp7                      | |/ _ \| | | | '_ \ / _ \ | | |    */
/*                                        | | (_) | |_| | | | |  __/ |_| |    */
/*  By: thomas <thomas@touhey.fr>         |_|\___/ \__,_|_| |_|\___|\__, |.fr */
/*  Last updated: 2017/01/04 15:01:48                               |___/     */
/*                                                                            */
/* ************************************************************************** */
#include <libp7/internals.h>

/**
 *	p7_checksum:
 *	Returns the checksum of a packet
 *
 *	The checksum is an unsigned integer that can fit in 8 bits.
 *
 *	@arg	packet		pointer to the packet
 *	@arg	size		the packet size (in bytes)
 *	@return				the checksum
 */

unsigned int p7_checksum(unsigned char *packet, p7ushort_t size)
{
	unsigned int sum = 0;
	/* remove type and checksum fields */
	packet++; size -= 3;

	/* add everything */
	while (size--)
		sum += *packet++;

	/* NOT + 1, as defined in fxReverse documentation.
	 * Be sure it's under 256! */
	return ((~sum + 1) & 0xFF);
}
